@@ -252,27 +252,51 @@ class NovaSecurityGroupRuleDelete(task_manager.Task):
         return client.nova_client.security_group_rules.delete(**self.args)
 
 
-# TODO: Do this with neutron instead of nova if possible
-class FloatingIPList(task_manager.Task):
+class NeutronFloatingIPList(task_manager.Task):
+    def main(self, client):
+        return client.neutron_client.list_floatingips(**self.args)
+
+
+class NovaFloatingIPList(task_manager.Task):
     def main(self, client):
         return client.nova_client.floating_ips.list()
 
 
-class FloatingIPCreate(task_manager.Task):
+class NeutronFloatingIPCreate(task_manager.Task):
+    def main(self, client):
+        return client.neutron_client.create_floatingip(**self.args)
+
+
+class NovaFloatingIPCreate(task_manager.Task):
     def main(self, client):
         return client.nova_client.floating_ips.create(**self.args)
 
 
-class FloatingIPDelete(task_manager.Task):
+class NeutronFloatingIPDelete(task_manager.Task):
+    def main(self, client):
+        return client.neutron_client.delete_floatingip(**self.args)
+
+
+class NovaFloatingIPDelete(task_manager.Task):
     def main(self, client):
         return client.nova_client.floating_ips.delete(**self.args)
 
 
-class FloatingIPAttach(task_manager.Task):
+class NovaFloatingIPAttach(task_manager.Task):
     def main(self, client):
         return client.nova_client.servers.add_floating_ip(**self.args)
 
 
+class NovaFloatingIPDetach(task_manager.Task):
+    def main(self, client):
+        return client.nova_client.servers.remove_floating_ip(**self.args)
+
+
+class NeutronFloatingIPUpdate(task_manager.Task):
+    def main(self, client):
+        return client.neutron_client.update_floatingip(**self.args)
+
+
 class FloatingIPPoolList(task_manager.Task):
     def main(self, client):
         return client.nova_client.floating_ip_pools.list()
@@ -403,6 +427,11 @@ class MachinePortList(task_manager.Task):
         return client.ironic_client.port.list()
 
 
+class MachineNodeGet(task_manager.Task):
+    def main(self, client):
+        return client.ironic_client.node.get(**self.args)
+
+
 class MachineNodeList(task_manager.Task):
     def main(self, client):
         return client.ironic_client.node.list(**self.args)
@@ -413,6 +442,11 @@ class MachineNodePortList(task_manager.Task):
         return client.ironic_client.node.list_ports(**self.args)
 
 
+class MachineNodeUpdate(task_manager.Task):
+    def main(self, client):
+        return client.ironic_client.node.update(**self.args)
+
+
 class MachineNodeValidate(task_manager.Task):
     def main(self, client):
         return client.ironic_client.node.validate(**self.args)
