@@ -71,6 +71,27 @@ def get_server_public_ip(server):
 
 
 def get_server_external_ipv4(cloud, server):
+    """Find an externally routable IP for the server.
+
+    There are 5 different scenarios we have to account for:
+
+    * Cloud has externally routable IP from neutron but neutron APIs don't
+      work (only info available is in nova server record) (rackspace)
+    * Cloud has externally routable IP from neutron (runabove, ovh)
+    * Cloud has externally routable IP from neutron AND supports optional
+      private tenant networks (vexxhost, unitedstack)
+    * Cloud only has private tenant network provided by neutron and requires
+      floating-ip for external routing (dreamhost, hp)
+    * Cloud only has private tenant network provided by nova-network and
+      requires floating-ip for external routing (auro)
+
+    :param cloud: the cloud we're working with
+    :param server: the server dict from which we want to get an IPv4 address
+    :return: a string containing the IPv4 address or None
+    """
+
+    if server['accessIPv4']:
+        return server['accessIPv4']
     if cloud.has_service('network'):
         try:
             # Search a fixed IP attached to an external net. Unfortunately
@@ -128,7 +149,9 @@ def get_server_external_ipv6(server):
     :param server: the server from which we want to get an IPv6 address
     :return: a string containing the IPv6 address or None
     """
-    addresses = find_nova_addresses(addresses=server.addresses, version=6)
+    if server['accessIPv6']:
+        return server['accessIPv6']
+    addresses = find_nova_addresses(addresses=server['addresses'], version=6)
     if addresses:
         return addresses[0]
     return None
@@ -180,9 +203,11 @@ def get_hostvars_from_server(cloud, server, mounts=None):
     server_vars = server
     server_vars.pop('links', None)
 
-    # Fist, add an IP address
-    server_vars['public_v4'] = get_server_external_ipv4(cloud, server)
-    server_vars['private_v4'] = get_server_private_ip(server)
+    # First, add an IP address. Set it to '' rather than None if it does
+    # not exist to remain consistent with the pre-existing missing values
+    server_vars['public_v4'] = get_server_external_ipv4(cloud, server) or ''
+    server_vars['public_v6'] = get_server_external_ipv6(server) or ''
+    server_vars['private_v4'] = get_server_private_ip(server) or ''
     if cloud.private:
         interface_ip = server_vars['private_v4']
     else:
@@ -190,6 +215,13 @@ def get_hostvars_from_server(cloud, server, mounts=None):
     if interface_ip:
         server_vars['interface_ip'] = interface_ip
 
+    # Some clouds do not set these, but they're a regular part of the Nova
+    # server record. Since we know them, go ahead and set them. In the case
+    # where they were set previous, we use the values, so this will not break
+    # clouds that provide the information
+    server_vars['accessIPv4'] = server_vars['public_v4']
+    server_vars['accessIPv6'] = server_vars['public_v6']
+
     server_vars['region'] = cloud.region_name
     server_vars['cloud'] = cloud.name
 
