@@ -37,6 +37,15 @@ class FakeFlavor(object):
         self.name = name
 
 
+class FakeFloatingIP(object):
+    def __init__(self, id, pool, ip, fixed_ip, instance_id):
+        self.id = id
+        self.pool = pool
+        self.ip = ip
+        self.fixed_ip = fixed_ip
+        self.instance_id = instance_id
+
+
 class FakeFloatingIPPool(object):
     def __init__(self, id, name):
         self.id = id
@@ -56,11 +65,15 @@ class FakeProject(object):
 
 
 class FakeServer(object):
-    def __init__(self, id, name, status, addresses=None):
+    def __init__(
+            self, id, name, status, addresses=None,
+            accessIPv4='', accessIPv6=''):
         self.id = id
         self.name = name
         self.status = status
         self.addresses = addresses
+        self.accessIPv4 = accessIPv4
+        self.accessIPv6 = accessIPv6
 
 
 class FakeService(object):
@@ -124,3 +137,10 @@ class FakeNovaSecgroupRule(object):
         if cidr:
             self.ip_range = {'cidr': cidr}
         self.parent_group_id = parent_group_id
+
+
+class FakeKeypair(object):
+    def __init__(self, id, name, public_key):
+        self.id = id
+        self.name = name
+        self.public_key = public_key
